#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.bergo.eng.br/eboard/

# Package name
NAME="eboard"
# Package version
VERSION="1.1.1"
# Source code URL
SOURCE="http://ovh.dl.sourceforge.net/sourceforge/eboard/eboard-$VERSION.tar.bz2"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL README TODO Documentation"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="52.1"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/eboard/eboard.png
fi

# Also download some extra themes
if [ -f eboard-extras-1pl2.tar.gz ]; then
	echo "Extra themes No 1 is here, no need to download";
else
 	echo "Downloading extra themes"
	wget -c http://switch.dl.sourceforge.net/sourceforge/eboard/eboard-extras-1pl2.tar.gz
fi

if [ -f eboard-extras-2.tar.gz ]; then
	echo "Extra themes No 2 is here, no need to download";
else
 	echo "Downloading extra themes"
	wget -c http://puzzle.dl.sourceforge.net/sourceforge/eboard/eboard-extras-2.tar.gz
fi

# Unpack source
tar xvjf $NAME-$VERSION.tar.bz2

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
# Patch Makefile for the proper C and CXX flags
sed -i -e 's/-O6/-O2 -march=i486 -mtune=i686/' Makefile
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Also add the extra themes and update the themes conf file
cd $CWD
tar xvzf eboard-extras-1pl2.tar.gz
tar xvzf eboard-extras-2.tar.gz
cp eboard-extras-1pl2/*.png $PKG/usr/share/eboard/
cp eboard-extras-1pl2/*.wav $PKG/usr/share/eboard/
cp eboard-extras-2/*.png $PKG/usr/share/eboard/
cp eboard-extras-2/*.wav $PKG/usr/share/eboard/
cat eboard-extras-1pl2/extras1.conf >> $PKG/usr/share/eboard/eboard_themes.conf
cat eboard-extras-2/extras2.conf >> $PKG/usr/share/eboard/eboard_themes.conf

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS	$PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: eboard - Chess board interface for playing and studying chess.
$NAME:
$NAME: eboard is a graphical client to internet chess servers, an
$NAME: interface to computer chess engines and a tool for visualization,
$NAME: analysis and study of chess games.
$NAME: This package includes both of the extra theme packs.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Place the icon in the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps/
cp $CWD/eboard.png $PKG/usr/share/icons/hicolor/48x48/apps/

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=eboard
Exec=eboard
Terminal=false
Type=Application
Categories=Game;BoardGame;
Icon=eboard
EOF

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $CWD/eboard-extras-1pl2
rm -rf $CWD/eboard-extras-2
rm -rf $PKG
